<?php

namespace Research\Subject\Policies;

use Litepie\User\Contracts\UserPolicy;
use Research\Subject\Models\Subject;

class SubjectPolicy
{

    /**
     * Determine if the given user can view the subject.
     *
     * @param UserPolicy $user
     * @param Subject $subject
     *
     * @return bool
     */
    public function view(UserPolicy $user, Subject $subject)
    {
        if ($user->canDo('subject.subject.view') && $user->isAdmin()) {
            return true;
        }

        return $subject->user_id == user_id() && $subject->user_type == user_type();
    }

    /**
     * Determine if the given user can create a subject.
     *
     * @param UserPolicy $user
     * @param Subject $subject
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('subject.subject.create');
    }

    /**
     * Determine if the given user can update the given subject.
     *
     * @param UserPolicy $user
     * @param Subject $subject
     *
     * @return bool
     */
    public function update(UserPolicy $user, Subject $subject)
    {
        if ($user->canDo('subject.subject.edit') && $user->isAdmin()) {
            return true;
        }

        return $subject->user_id == user_id() && $subject->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given subject.
     *
     * @param UserPolicy $user
     * @param Subject $subject
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Subject $subject)
    {
        return $subject->user_id == user_id() && $subject->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given subject.
     *
     * @param UserPolicy $user
     * @param Subject $subject
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Subject $subject)
    {
        if ($user->canDo('subject.subject.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given subject.
     *
     * @param UserPolicy $user
     * @param Subject $subject
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Subject $subject)
    {
        if ($user->canDo('subject.subject.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
